==> cmsmadesimple-1.5.3.tgz: cms/modules/TinyMCE/lang/ext/lt_LT.php <==
<?php
$lang['friendlyname'] = 'TinyMCE  WYSIWYG';
$lang['stripbackgroundtags'] = 'I&scaron;imti Background žymes i&scaron; CSS';
$lang['source_formatting_text'] = 'Pritaikyti kodo formatavimą HTML vaizdavimui';
$lang['dropdownblockformats_text'] = 'Neleidžiami formatai i&scaron;&scaron;okančiam pasirenkamam meniu';
$lang['allowtables'] = 'Leisti lentelių naudojimą';
$lang['newlinestyle_text'] = 'Naujos eilutės stilius';
$lang['pstyle'] = 'p stilius';
$lang['brstyle'] = 'br stilius';
$lang['usecompressiontext'] = 'Naudoti gz suspaudimą';
$lang['usecompressionhelp'] = 'Tai gali pagreitinti  TinyMCE, bet kai kuriose sistemose gali neužkrauti. Naudokite atsargiai.';
$lang['forcedrootblocktext'] = 'Priverstinis <p> naudojimas';
$lang['forcedrootblockhelp'] = 'Priversti pastraipas naudoti <p>-tag';
$lang['filepickerstyle'] = 'Bylų pasirinkimo stilius';
$lang['filepickersize'] = 'Bylų pasirinkimo dydis';
$lang['filenameonly'] = 'Rodyti pavadinimus';
$lang['thumbnailsonly'] = 'Rodyti miniatiūras';
$lang['filenameandthumbnails'] = 'Rodyti tiek miniatiūras tiek pavadinimus';
$lang['skinstext'] = 'Oda';
$lang['skinvariationtext'] = 'Odos variacija';
$lang['advancedwarning'] = '<strong>Pra&scaron;ome atminti!<br/>
Pakeisdami &scaron;ias nuostatas TinyMCE gali nebeveikti ar generuoti kodą neteisingai. Čia redaguokite jei žinote ką darote. Pra&scaron;ome pasikonsultuoti TinyMCE svetainėje prie&scaron; keičiant.</strong>';
$lang['entityencoding_text'] = 'Kodavimas';
$lang['rawencoding'] = 'Pavir&scaron;utinis kodavimas (greičiausias, veikia daugeliu atveju)';
$lang['namedencoding'] = 'Pavadintas kodavimas (kaip &nbsp;)';
$lang['numericencoding'] = 'Skaitinis kodavimas (kaip &amp;amp;#160;)';
$lang['show_path_text'] = 'Rodyti elemento kelia redaktoriaus apačioje';
$lang['toolbar_tab'] = 'Įrankinė ';
$lang['toolbar_help'] = '&Scaron;ios nuostatos turėtų būt sudarytos i&scaron; kableliu atskirtų mygtukų pavadinimų.';
$lang['toolbar_text'] = 'Įrankinė ';
$lang['toolbarhelptext'] = 'Spauskite čia jei norite peržiūrėti TinyMCE įrankinės instrikcija.';
$lang['editor_width_text'] = 'Redaktoriaus lauko plotis';
$lang['editor_height_text'] = 'Redaktoriaus lauko auk&scaron;tis';
$lang['auto'] = 'Automatinis';
$lang['or'] = 'ar';
$lang['datetimeformat_text'] = 'Datos/Laiko formatas';
$lang['timetext'] = 'Laikas';
$lang['datetext'] = 'Data';
$lang['datetimeformat_help'] = 'Spauskite čia jei norite pagalbos dėl laiko datos formatavimo';
$lang['extraconfigtext'] = 'Papildomi nustatymai';
$lang['extraconfighelp'] = 'Patikrinkite TinyMCE-wiki';
$lang['customdropdowntext'] = 'Savitas i&scaron;skleidžiamasis meniu';
$lang['customdropdownhelp'] = 'Įterpia savitus kodo teksto fragmentus į i&scaron;skleidžiamąjį meniu. Naudojama paprastesniam žymių naudojimui. Meniu įterpiamas į įrankinę naudojant &#039;customdropdown&#039;.
';
$lang['loadcmslinkertext'] = 'Užkrauti CMS-linker';
$lang['loadcmslinkerhelp'] = 'Tai sugeneruoja javascript-kodą reikalingą pridėti į įrankinę
';
$lang['cmslinkerstyletext'] = 'CMS-linker nuorodų stilius';
$lang['cmsselflinkstyle'] = '{cms_selflink}-stilius (palaiko &scaron;varius url)';
$lang['ahrefstyle'] = '<a href>-stilius (nepalaiko &scaron;varių url)';
$lang['relativeurlstext'] = 'Generuoti giminingus url';
$lang['forcecleanpastetext'] = 'Priverstinis &scaron;varus įterpimas (paste)';
$lang['forcecleanpastehelp'] = 'Tai turėtų būt įjungta jei norite pa&scaron;alinti keistą Word formatavimą kai įterpiamas tekstas.';
$lang['bodycss_text'] = 'Body tag&#039;as CSS';
$lang['bodycss_help'] = 'Bus pridėtas į css body-apibrėžimą';
$lang['showtogglebutton_text'] = 'Rodyti žyminą laukelį i&scaron;jungti/įjungti  WYSIWYG';
$lang['togglewysiwyg'] = 'Įjungti/i&scaron;jungti WYSIWYG';
$lang['styles_tab'] = 'CSS Stiliai';
$lang['styles_help'] = 'Jei paliksite tu&scaron;čia, TinyMCE naudos CSS bylą ir stilius esančius joje. Jei norite leisti nariams naudoti tik tam tikrus stilius nurodykite juos forma &quot;SavitasPavadinimas1=stilius1; SavitasPavadinimas2=tilius2&quot; pirmame laukelyje';
$lang['css_styles_text'] = 'Stiliai';
$lang['accessdenied'] = 'Prieiga uždrausta. Pasitirinkite leidimus.';
$lang['error'] = 'Klaida!';
$lang['submit'] = 'Pateikti';
$lang['update'] = 'Atnaujinti';
$lang['settings'] = 'Nuostatos';
$lang['settingssaved'] = 'Nuostatos i&scaron;saugotos';
$lang['advancedsaved'] = 'Pažangesnės nuostatos i&scaron;saugotos';
$lang['toolbarsaved'] = 'Įrankinė i&scaron;saugoti';
$lang['stylessaved'] = 'Stiliai i&scaron;saugoti';
$lang['testareatext'] = 'Testavimo erdvė, joks tekstas nebus i&scaron;saugotas testavimo metu..';
$lang['reset'] = 'Atstatyti į pradinius';
$lang['resetall'] = 'Nustatyti visas nuostatas į pradines';
$lang['confirmreset'] = 'Ar tikrai norite atstatyti nuostatas į pradinies?';
$lang['confirmresetall'] = 'Ar tikrai norite atstatyti VISAS nuostatas į pradinies?';
$lang['settingsreset'] = 'Nuostatos atstatytos';
$lang['allsettingsreset'] = 'Visos nuostatos atstatytos';
$lang['upgraded'] = 'buvo atnaujinta į versija';
$lang['customdropdown'] = 'Savitas i&scaron;skleidžiamasis meniu';
$lang['cmsmslinker'] = 'Įterpti nuorodą į cmsms-puslapį';
$lang['backend_toolbars'] = 'Administratoriaus įrankinės nuostatos';
$lang['frontend_toolbars'] = 'Prie&scaron;akinės įrankinės nuostatos';
$lang['plugins_tab'] = 'Plėtiniai';
$lang['plugins_help'] = 'Pasirinkite kokius plėtinius norite aktyvuoti. Dokumentacija rasite <a href=&quot;http://wiki.moxiecode.com/index.php/TinyMCE:Plugins&quot; target=&quot;_blank&quot;>čia</a>';
$lang['plugins_text'] = 'Plėtiniai';
$lang['saveplugins'] = 'I&scaron;saugoti plėtinius';
$lang['pluginssaved'] = 'Plėtiniai i&scaron;saugoti';
$lang['youareintext'] = 'Jūs esate';
$lang['filepickertitle'] = 'CMSMadeSimple Bylų pasirinkimas';
$lang['thousanddelimiter'] = ', ';
$lang['size'] = 'Dydis';
$lang['dimensions'] = 'hxw';
$lang['advanced_tab'] = 'Papildomai';
$lang['help'] = '	<h3>Ką jis daro?</h3>
	<p>Naudoja TinyMCE kaip WYSIWYG html redaktorių.</p>
	<h3>Kaip jį naudoti?</h3>
	<p>Įdiegite jį, nueikite į Vartotojo Nustatymus ir pažymėkite, kad norite naudoti TinyMCE kaip WYSIWYG redaktorių.</p>';
$lang['changelog'] = '<ul>
		<li>
		<p>Version: 2.4.0</p>
		<p>Distributed with CMSMS 1.3</p>
		</li>
		<li>		
		<p>Version: 2.4.0b5</p>		
		<p>Added help for toolbar</p>
		<p>Added cmslinker-style</p>
		<p>Added Filepicker-style</p>
		<p>Fixed the bug where content changes was undon when wysiwyg was disabled with the check box</p>
		<p>Added option to turn reletive-urls off</p>
		<p>Nuno redesigned filepicker dialogue</p>				
		<p>Added customizable dimensions of FilePicker</p>
		<p>Numerous bug fixes</p>	
		</li>
		<li>
		<p>Version: 2.4.0b4</p>		
		<p>Enabled extraconfig-option</p>
		<p>Implemented option for forced_root_block</p>
		<p>Work on supported pretty-urls, thanks Nuno!</p>
		<p>Updated to Tiny 3.0.8</p>					
		</li>
		<li>
		<p>Version: 2.4.0b3</p>		
		<p>Fixed frontend usage</p>
		<p>added a couple of upgrades from cmsmslink-plugin to cmslinker</p>		
		<p>Added links for pluginhelp</p>
		<p>Fixed js-error breaking editor in IE</p>
		<p>Added buttons for resetting to default values</p>
		</li>
		<li>
		<p>Version: 2.4.0b2</p>		
		<p>Did prettier default value for custommenu</p>
		<p>Fixed htmlentity problems in cmslinker-part crashing whole editor</p>		
		</li>
		<li>
		<p>Version: 2.4.0b1</p>		
		<p></p>
		<p>Upgraded to latest TinyMCE</p>
		<p>Cmsms-linker reimplemented</p>
		<p>Custom dropdownmenu implemented</p>
		<p>Filepicker bugs fixed, linke using it for linking to non-image-files</p>
		<p>stylesheet code rewritten using adodb instead of plain mysql/pgsql. should be lots safer now</p>
		</li>
		<li>
		<p>Version: 2.4.0a2</p>		
		<p></p>
		<p>Upgraded to latest TinyMCE</p>
		<p>Toolbars for frontend/backend can now be configured seperately</p>
		<p>Filepicker reimplemented, simple for now, but works</p>
		</li>
		<li>
		<p>Version: 2.4.0a1</p>		
		<p></p>
		<p>Upgraded to TinyMCE 3.0</p>		
		<p>Stopped the stupid seperation between advanced and basic version. Now only this one is in development, kept as trim as possible, but with lots of plugins</p>		
		<p>Started organizing admin-settings logically</p>
		</li>
		<li>
		<p>Version: 2.2.7</p>		
		<p>Fixed injection vulnerability in content_css.php</p>
		</li>
		<li>
		<p>Version: 2.2.6</p>
		<p>Made file uploading through simplebrowser honor default_upload_permission</p>		
		</li>
		<li>
		<p>Version: 2.2.5</p>
		<p>Made the entityencoding a preference</p>
		<p>Made Tiny work as frontend wysiwyg module</p>		
		<p>Fixed missing blockformat default upon new installation (thanks Utter for noticing)</p>
		</li>
		<li>
		<p>Version: 2.2.4</p>
		<p>Fixed the IE toggle bug</p>
		<p>Speeded up turning editor on/off quite a bit (using mceToggleEditor in stead of loading/unloading whole system)</p>
		</li>
		<li>
		<p>Version: 2.2.3</p>
		<p>Updated to TinyMCE version 2.1.2, fixes turning wysiwyg on/off on pages containing multiple textareas</p>
		<p>Fixed a bug making you end up in wrong tab when saving toolbar</p>		
		<p></p>
		</li>
    <li>
		<p>Version: 2.2.2</p>
		<p>Numereous smaller tweeks.</p>
    <p>Fixed problem with changing between pages with Tiny and EditArea.</p>
    <p>Sessionized the live language.</p>
    <p>Added charmap to default toolbar.</p>
		</li>
		<li>
		<p>Version: 2.2.1</p>
		<p>Fixed blockformat dropdown now actually reflecting the values in the edit box</p>
		<p>Rewrote textarea management to using sessions. Should fix the double-tinys appearing randomly.</p>
		</li>
    <li>
		<p>Version: 2.2.0</p>
		<p>Split TinyMCE into 2 modules, one for inclusion in distribution and one for more advanced use. This is the Basic version.</p>
		<p>Made table operations an option</p>
		<p>Removed the nonworking &#039;replace cms-links while writing&#039;</p>
		<p>Generally trimmed down the module to a size acceptable for the main distribution</p>
		</li>
    <li>
		<p>Version: 2.0.6</p>
		<p>Made it possible to add something extra to the configuration</p>
		<p>Added paste as plain text plugin</p>
		<p>Added an option to show a button turning the wysiwyg-functionality on/off</p>
		<p>General speed improvements</p>
		<p>Updated to Tiny 2.1.1, TinyCompressed 1.1.0 and SpellChecker 1.0.4</p>
		</li>
		<li>
		<p>Version: 2.0.5</p>
		<p>Added a xhtml-elements only option</p>
		<p>Moved javascript config into an external file</p>
		<p>Added selecting p or br/ style newlines</p>
		<p>Updated to new compression engine. Should fix some bugs related to this</p>
		<p>Added plugin descriptions from docs</p>
		<p>Fixed showing of correct testarea even if another wysiwyg is chosen</p>
		<p>Updated to Tiny 2.1.0</p>
		<p>Added thumbnail previews in image browser.</p>
		</li>
		<li>
		<p>Version: 2.0.4</p>
		<p>Fixed customized textarea width</p>
		<p>Updated to Tiny 2.0.7</p>
		<p>Reversed changelog content (from now on at least) ;-)</p>
		<p></p>
		</li>

		<li>
		<p>Version: 1.0</p>
		<p>Original module code for TinyMCE WYSIWYG textarea replacement tool.</p>
		</li>
		<li>
		<p>Author: Simon Brown &amp;lt;simon@uptoeleven.ws&amp;gt;</p>
		<p>Version: 1.1</p>
		<p>Converted for use with new CMS Module architecture.</p>
		<p>Upgraded TinyMCE to version 1.42.</p>
		</li>
		<li>
		<p>Version: 1.2</p>
		<p>Fixed bug with paths being created wrong on image insert.</p>
		</li>
		<li>
		<p>Version: 2.0.0</p>
		<p>Author: Stefan R&amp;ouml;llin</p>
		<p>UPDATED to version 2.0.5.1 of TinyMCE editor.</p>
		<p>ADD plugins simplebrowser, cmsmslink </p>
		<p>ADD some configuration options.</p>
		<p>ADD permission to modify settings.</p>
		</li>
		<li>
		<p>Version: 2.0.1</p>
		<p>UPDATED to version 2.0.6.1 of TinyMCE editor.</p>
		<p>ADD configuration options: language and source_formatting.</p>
		<p>Improved plugin configuration.</p>
		<p>ADD more languages.</p>
		</li>
		<li>
		<p>Version: 2.0.2</p>
		<p>FIX filebrowser</p>
		<p>FIX security flaw in filebrowser</p>
		</li>
		<li>
		<p>Version: 2.0.3</p>
		<p>Converted to new fetch-method of content_array</p>
		<p>FIX security flaw in filebrowser</p>
		<p>Added localization of testarea-text</p>
		</li>
		</ul>';
$lang['utma'] = '156861353.434555129.1206704373.1212477313.1212497022.37';
$lang['utmz'] = '156861353.1212140966.35.21.utmccn=(referral)|utmcsr=localhost|utmcct=/cmsmadesimple125/admin/moduleinterface.php|utmcmd=referral';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.6.6.tgz: cms/modules/TinyMCE/lang/ext/lt_LT.php <==
<?php
$lang['friendlyname'] = 'TinyMCE  WYSIWYG';
$lang['stripbackgroundtags'] = 'I&scaron;imti Background žymes i&scaron; CSS';
$lang['source_formatting_text'] = 'Pritaikyti kodo formatavimą HTML vaizdavimui';
$lang['dropdownblockformats_text'] = 'Neleidžiami formatai i&scaron;&scaron;okančiam pasirenkamam meniu';
$lang['allowtables'] = 'Leisti lentelių naudojimą';
$lang['newlinestyle_text'] = 'Naujos eilutės stilius';
$lang['pstyle'] = 'p stilius';
$lang['brstyle'] = 'br stilius';
$lang['usecompressiontext'] = 'Naudoti gz suspaudimą';
$lang['usecompressionhelp'] = 'Tai gali pagreitinti  TinyMCE, bet kai kuriose sistemose gali neužkrauti. Naudokite atsargiai.';
$lang['forcedrootblocktext'] = 'Priverstinis <p> naudojimas';
$lang['forcedrootblockhelp'] = 'Priversti pastraipas naudoti <p>-tag';
$lang['filepickerstyle'] = 'Bylų pasirinkimo stilius';
$lang['filepickersize'] = 'Bylų pasirinkimo dydis';
$lang['filenameonly'] = 'Rodyti pavadinimus';
$lang['thumbnailsonly'] = 'Rodyti miniatiūras';
$lang['filenameandthumbnails'] = 'Rodyti tiek miniatiūras tiek pavadinimus';
$lang['skinstext'] = 'Oda';
$lang['skinvariationtext'] = 'Odos variacija';
$lang['advancedwarning'] = '<strong>Pra&scaron;ome atminti!<br/>
Pakeisdami &scaron;ias nuostatas TinyMCE gali nebeveikti ar generuoti kodą neteisingai. Čia redaguokite jei žinote ką darote. Pra&scaron;ome pasikonsultuoti TinyMCE svetainėje prie&scaron; keičiant.</strong>';
$lang['entityencoding_text'] = 'Kodavimas';
$lang['rawencoding'] = 'Pavir&scaron;utinis kodavimas (greičiausias, veikia daugeliu atveju)';
$lang['namedencoding'] = 'Pavadintas kodavimas (kaip &nbsp;)';
$lang['numericencoding'] = 'Skaitinis kodavimas (kaip &amp;amp;#160;)';
$lang['show_path_text'] = 'Rodyti elemento kelia redaktoriaus apačioje';
$lang['toolbar_tab'] = 'Įrankinė ';
$lang['toolbar_help'] = '&Scaron;ios nuostatos turėtų būt sudarytos i&scaron; kableliu atskirtų mygtukų pavadinimų.';
$lang['toolbar_text'] = 'Įrankinė ';
$lang['toolbarhelptext'] = 'Spauskite čia jei norite peržiūrėti TinyMCE įrankinės instrikcija.';
$lang['editor_width_text'] = 'Redaktoriaus lauko plotis';
$lang['editor_height_text'] = 'Redaktoriaus lauko auk&scaron;tis';
$lang['auto'] = 'Automatinis';
$lang['or'] = 'ar';
$lang['datetimeformat_text'] = 'Datos/Laiko formatas';
$lang['timetext'] = 'Laikas';
$lang['datetext'] = 'Data';
$lang['datetimeformat_help'] = 'Spauskite čia jei norite pagalbos dėl laiko datos formatavimo';
$lang['extraconfigtext'] = 'Papildomi nustatymai';
$lang['extraconfighelp'] = 'Patikrinkite TinyMCE-wiki';
$lang['customdropdowntext'] = 'Savitas i&scaron;skleidžiamasis meniu';
$lang['customdropdownhelp'] = 'Įterpia savitus kodo teksto fragmentus į i&scaron;skleidžiamąjį meniu. Naudojama paprastesniam žymių naudojimui. Meniu įterpiamas į įrankinę naudojant &#039;customdropdown&#039;.
';
$lang['loadcmslinkertext'] = 'Užkrauti CMS-linker';
$lang['loadcmslinkerhelp'] = 'Tai sugeneruoja javascript-kodą reikalingą pridėti į įrankinę
';
$lang['cmslinkerstyletext'] = 'CMS-linker nuorodų stilius';
$lang['cmsselflinkstyle'] = '{cms_selflink}-stilius (palaiko &scaron;varius url)';
$lang['ahrefstyle'] = '<a href>-stilius (nepalaiko &scaron;varių url)';
$lang['relativeurlstext'] = 'Generuoti giminingus url';
$lang['forcecleanpastetext'] = 'Priverstinis &scaron;varus įterpimas (paste)';
$lang['forcecleanpastehelp'] = 'Tai turėtų būt įjungta jei norite pa&scaron;alinti keistą Word formatavimą kai įterpiamas tekstas.';
$lang['bodycss_text'] = 'Body tag&#039;as CSS';
$lang['bodycss_help'] = 'Bus pridėtas į css body-apibrėžimą';
$lang['showtogglebutton_text'] = 'Rodyti žyminą laukelį i&scaron;jungti/įjungti  WYSIWYG';
$lang['togglewysiwyg'] = 'Įjungti/i&scaron;jungti WYSIWYG';
$lang['styles_tab'] = 'CSS Stiliai';
$lang['styles_help'] = 'Jei paliksite tu&scaron;čia, TinyMCE naudos CSS bylą ir stilius esančius joje. Jei norite leisti nariams naudoti tik tam tikrus stilius nurodykite juos forma &quot;SavitasPavadinimas1=stilius1; SavitasPavadinimas2=tilius2&quot; pirmame laukelyje';
$lang['css_styles_text'] = 'Stiliai';
$lang['accessdenied'] = 'Prieiga uždrausta. Pasitirinkite leidimus.';
$lang['error'] = 'Klaida!';
$lang['submit'] = 'Pateikti';
$lang['update'] = 'Atnaujinti';
$lang['settings'] = 'Nuostatos';
$lang['settingssaved'] = 'Nuostatos i&scaron;saugotos';
$lang['advancedsaved'] = 'Pažangesnės nuostatos i&scaron;saugotos';
$lang['toolbarsaved'] = 'Įrankinė i&scaron;saugoti';
$lang['stylessaved'] = 'Stiliai i&scaron;saugoti';
$lang['testareatext'] = '<p>Testavimo erdvė, joks tekstas nebus i&scaron;saugotas testavimo metu...</p>';
$lang['reset'] = 'Atstatyti į pradinius';
$lang['resetall'] = 'Nustatyti visas nuostatas į pradines';
$lang['confirmreset'] = 'Ar tikrai norite atstatyti nuostatas į pradinies?';
$lang['confirmresetall'] = 'Ar tikrai norite atstatyti VISAS nuostatas į pradinies?';
$lang['settingsreset'] = 'Nuostatos atstatytos';
$lang['allsettingsreset'] = 'Visos nuostatos atstatytos';
$lang['upgraded'] = 'buvo atnaujinta į versija';
$lang['customdropdown'] = 'Savitas i&scaron;skleidžiamasis meniu';
$lang['cmsmslinker'] = 'Įterpti nuorodą į cmsms-puslapį';
$lang['backend_toolbars'] = 'Administratoriaus įrankinės nuostatos';
$lang['frontend_toolbars'] = 'Prie&scaron;akinės įrankinės nuostatos';
$lang['plugins_tab'] = 'Plėtiniai';
$lang['plugins_help'] = 'Pasirinkite kokius plėtinius norite aktyvuoti. Dokumentacija rasite <a href=&quot;http://wiki.moxiecode.com/index.php/TinyMCE:Plugins&quot; target=&quot;_blank&quot;>čia</a>';
$lang['plugins_text'] = 'Plėtiniai';
$lang['saveplugins'] = 'I&scaron;saugoti plėtinius';
$lang['pluginssaved'] = 'Plėtiniai i&scaron;saugoti';
$lang['youareintext'] = 'Jūs esate';
$lang['filepickertitle'] = 'CMSMadeSimple Bylų pasirinkimas';
$lang['thousanddelimiter'] = ', ';
$lang['size'] = 'Dydis';
$lang['dimensions'] = 'hxw';
$lang['advanced_tab'] = 'Papildomai';
$lang['help'] = '	<h3>Ką jis daro?</h3>
	<p>Naudoja TinyMCE kaip WYSIWYG html redaktorių.</p>
	<h3>Kaip jį naudoti?</h3>
	<p>Įdiegite jį, nueikite į Vartotojo Nustatymus ir pažymėkite, kad norite naudoti TinyMCE kaip WYSIWYG redaktorių.</p>';
$lang['changelog'] = '<ul>
		<li>
		<p>Version: 2.4.0</p>
		<p>Distributed with CMSMS 1.3</p>
		</li>
		<li>		
		<p>Version: 2.4.0b5</p>		
		<p>Added help for toolbar</p>
		<p>Added cmslinker-style</p>
		<p>Added Filepicker-style</p>
		<p>Fixed the bug where content changes was undon when wysiwyg was disabled with the check box</p>
		<p>Added option to turn reletive-urls off</p>
		<p>Nuno redesigned filepicker dialogue</p>				
		<p>Added customizable dimensions of FilePicker</p>
		<p>Numerous bug fixes</p>	
		</li>
		<li>
		<p>Version: 2.4.0b4</p>		
		<p>Enabled extraconfig-option</p>
		<p>Implemented option for forced_root_block</p>
		<p>Work on supported pretty-urls, thanks Nuno!</p>
		<p>Updated to Tiny 3.0.8</p>					
		</li>
		<li>
		<p>Version: 2.4.0b3</p>		
		<p>Fixed frontend usage</p>
		<p>added a couple of upgrades from cmsmslink-plugin to cmslinker</p>		
		<p>Added links for pluginhelp</p>
		<p>Fixed js-error breaking editor in IE</p>
		<p>Added buttons for resetting to default values</p>
		</li>
		<li>
		<p>Version: 2.4.0b2</p>		
		<p>Did prettier default value for custommenu</p>
		<p>Fixed htmlentity problems in cmslinker-part crashing whole editor</p>		
		</li>
		<li>
		<p>Version: 2.4.0b1</p>		
		<p></p>
		<p>Upgraded to latest TinyMCE</p>
		<p>Cmsms-linker reimplemented</p>
		<p>Custom dropdownmenu implemented</p>
		<p>Filepicker bugs fixed, linke using it for linking to non-image-files</p>
		<p>stylesheet code rewritten using adodb instead of plain mysql/pgsql. should be lots safer now</p>
		</li>
		<li>
		<p>Version: 2.4.0a2</p>		
		<p></p>
		<p>Upgraded to latest TinyMCE</p>
		<p>Toolbars for frontend/backend can now be configured seperately</p>
		<p>Filepicker reimplemented, simple for now, but works</p>
		</li>
		<li>
		<p>Version: 2.4.0a1</p>		
		<p></p>
		<p>Upgraded to TinyMCE 3.0</p>		
		<p>Stopped the stupid seperation between advanced and basic version. Now only this one is in development, kept as trim as possible, but with lots of plugins</p>		
		<p>Started organizing admin-settings logically</p>
		</li>
		<li>
		<p>Version: 2.2.7</p>		
		<p>Fixed injection vulnerability in content_css.php</p>
		</li>
		<li>
		<p>Version: 2.2.6</p>
		<p>Made file uploading through simplebrowser honor default_upload_permission</p>		
		</li>
		<li>
		<p>Version: 2.2.5</p>
		<p>Made the entityencoding a preference</p>
		<p>Made Tiny work as frontend wysiwyg module</p>		
		<p>Fixed missing blockformat default upon new installation (thanks Utter for noticing)</p>
		</li>
		<li>
		<p>Version: 2.2.4</p>
		<p>Fixed the IE toggle bug</p>
		<p>Speeded up turning editor on/off quite a bit (using mceToggleEditor in stead of loading/unloading whole system)</p>
		</li>
		<li>
		<p>Version: 2.2.3</p>
		<p>Updated to TinyMCE version 2.1.2, fixes turning wysiwyg on/off on pages containing multiple textareas</p>
		<p>Fixed a bug making you end up in wrong tab when saving toolbar</p>		
		<p></p>
		</li>
    <li>
		<p>Version: 2.2.2</p>
		<p>Numereous smaller tweeks.</p>
    <p>Fixed problem with changing between pages with Tiny and EditArea.</p>
    <p>Sessionized the live language.</p>
    <p>Added charmap to default toolbar.</p>
		</li>
		<li>
		<p>Version: 2.2.1</p>
		<p>Fixed blockformat dropdown now actually reflecting the values in the edit box</p>
		<p>Rewrote textarea management to using sessions. Should fix the double-tinys appearing randomly.</p>
		</li>
    <li>
		<p>Version: 2.2.0</p>
		<p>Split TinyMCE into 2 modules, one for inclusion in distribution and one for more advanced use. This is the Basic version.</p>
		<p>Made table operations an option</p>
		<p>Removed the nonworking &#039;replace cms-links while writing&#039;</p>
		<p>Generally trimmed down the module to a size acceptable for the main distribution</p>
		</li>
    <li>
		<p>Version: 2.0.6</p>
		<p>Made it possible to add something extra to the configuration</p>
		<p>Added paste as plain text plugin</p>
		<p>Added an option to show a button turning the wysiwyg-functionality on/off</p>
		<p>General speed improvements</p>
		<p>Updated to Tiny 2.1.1, TinyCompressed 1.1.0 and SpellChecker 1.0.4</p>
		</li>
		<li>
		<p>Version: 2.0.5</p>
		<p>Added a xhtml-elements only option</p>
		<p>Moved javascript config into an external file</p>
		<p>Added selecting p or br/ style newlines</p>
		<p>Updated to new compression engine. Should fix some bugs related to this</p>
		<p>Added plugin descriptions from docs</p>
		<p>Fixed showing of correct testarea even if another wysiwyg is chosen</p>
		<p>Updated to Tiny 2.1.0</p>
		<p>Added thumbnail previews in image browser.</p>
		</li>
		<li>
		<p>Version: 2.0.4</p>
		<p>Fixed customized textarea width</p>
		<p>Updated to Tiny 2.0.7</p>
		<p>Reversed changelog content (from now on at least) ;-)</p>
		<p></p>
		</li>

		<li>
		<p>Version: 1.0</p>
		<p>Original module code for TinyMCE WYSIWYG textarea replacement tool.</p>
		</li>
		<li>
		<p>Author: Simon Brown &amp;lt;simon@uptoeleven.ws&amp;gt;</p>
		<p>Version: 1.1</p>
		<p>Converted for use with new CMS Module architecture.</p>
		<p>Upgraded TinyMCE to version 1.42.</p>
		</li>
		<li>
		<p>Version: 1.2</p>
		<p>Fixed bug with paths being created wrong on image insert.</p>
		</li>
		<li>
		<p>Version: 2.0.0</p>
		<p>Author: Stefan R&amp;ouml;llin</p>
		<p>UPDATED to version 2.0.5.1 of TinyMCE editor.</p>
		<p>ADD plugins simplebrowser, cmsmslink </p>
		<p>ADD some configuration options.</p>
		<p>ADD permission to modify settings.</p>
		</li>
		<li>
		<p>Version: 2.0.1</p>
		<p>UPDATED to version 2.0.6.1 of TinyMCE editor.</p>
		<p>ADD configuration options: language and source_formatting.</p>
		<p>Improved plugin configuration.</p>
		<p>ADD more languages.</p>
		</li>
		<li>
		<p>Version: 2.0.2</p>
		<p>FIX filebrowser</p>
		<p>FIX security flaw in filebrowser</p>
		</li>
		<li>
		<p>Version: 2.0.3</p>
		<p>Converted to new fetch-method of content_array</p>
		<p>FIX security flaw in filebrowser</p>
		<p>Added localization of testarea-text</p>
		</li>
		</ul>';
$lang['utma'] = '156861353.434555129.1206704373.1212477313.1212497022.37';
$lang['utmz'] = '156861353.1212140966.35.21.utmccn=(referral)|utmcsr=localhost|utmcct=/cmsmadesimple125/admin/moduleinterface.php|utmcmd=referral';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
